use Test::More;

use_ok( 'HTML::FormHandler::Model' );
use_ok( 'HTML::FormHandler' );
use_ok( 'HTML::FormHandler::Field' );
use_ok( 'HTML::FormHandler::Field::Select' );
use_ok( 'HTML::FormHandler::Field::Compound' );
use_ok( 'HTML::FormHandler::Field::Repeatable' );

use_ok( 'HTML::FormHandler::Model::CDBI' );

done_testing;
